css_color = """
<style>

.dark-mode {{
  background-color: black;
  color: white;
    }}

{}

/*SWITCH*/
.switch {{
  position: relative;
  display: inline-block;
  width: 60px;
  height: 34px;
  align-self: center;
}}

.switch-container{{
  float: right;
  display: flex;
  padding-top: 10px;
}}

.switch-container .switch-description{{
  margin-top: 6px;
  padding-right: 8px;
  
}}

.switch input {{
  opacity: 0;
  width: 0;
  height: 0;
}}

.slider {{
  position: absolute;
  cursor: pointer;
  top: 0;
  left: 0;
  right: 0;
  bottom: 0;
  background-color: #ccc;
  -webkit-transition: 0.4s;
  transition: 0.4s;
}}

.slider:before {{
  position: absolute;
  content: "";
  height: 26px;
  width: 26px;
  left: 4px;
  bottom: 4px;
  background-color: white;
  -webkit-transition: 0.4s;
  transition: 0.4s;
}}

input:checked + .slider {{
  background-color: #2196f3;
}}

input:checked + .slider:before {{
  -webkit-transform: translateX(26px);
  -ms-transform: translateX(26px);
  transform: translateX(26px);
}}

/* Rounded sliders */
.slider {{
  border-radius: 30px;
}}

.slider:before {{
  border-radius: 50%;
}}

.text-column {{
  overflow-wrap: break-word;
}}

.color-mode-container {{
  float: right;
}}

</style>
"""
